/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/types.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <wait.h>

#define INPUTSIZ	256

void doshell(char *);
extern void error(const char *fmt, ...);
extern void fatal(const char *fmt, ...);

void
main()
{
	char buf[INPUTSIZ];

	/*
	 * Print the initial prompt.
	 */
	printf("> ");

	/*
	 * While the user is providing input, read a command,
	 * execute it in a subshell, and print the next prompt.
	 */
	while (fgets(buf, INPUTSIZ, stdin) != NULL) {
		doshell(buf);
		printf("> ");
	}
	exit(0);
}

void
doshell(char *cmd)
{
	pid_t pid;

	/*
	 * Create a child process to execute the command.
	 */
	if ((pid = fork()) < 0) {
		error("fork failed");
		return;
	}
	if (pid == 0) {
		/*
		 * The child executes the command in a
		 * subshell.  This implies the command
		 * can be a shell script.
		 */
		execl("/sbin/sh", "sh", "-c", cmd, NULL);
		fatal("exec failed");
	}

	/*
	 * The parent waits for the child to exit
	 * before returning.
	 */
	if (waitpid(pid, NULL, 0) < 0)
		fatal("waitpid failed");
}
