/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/utsname.h>
#include <rpc/rpc.h>
#include <stdio.h>
#include <stdlib.h>
#include "machtype.h"

static char **mach_type_1(void);
extern void daemonize(const char *);
extern void log(const char *, ...);

void
main()
{
	/*
	 * Become a daemon.
	 */
	daemonize("mtyped");

	/*
	 * Register with the rpcbinder.
	 */
	if (rpc_reg(MACH_PROG, MACH_VER, MACH_PROC,
	  mach_type_1, xdr_void, xdr_machtype,
	  "visible") < 0) {
		log("error: cannot start service");
		exit(1);
	}

	/*
	 * Wait for requests and service them.
	 */
	svc_run();

	/*
	 * svc_run should never return.
	 */
	log("error: unexpected return from svc_run");
	exit(1);
}

static char **
mach_type_1(void)
{
	static struct utsname u;
	static char *p;

	/*
	 * If uname fails, return the address of
	 * a NULL pointer.
	 */
	p = NULL;
	if (uname(&u) >= 0)
		p = u.machine;
	return(&p);
}
